# USB Gadget Manager
A simple utility program to configure Linux USB gadgets, featuring a terminal-based user interface. This initial version only supports the `USB Audio Gadget` and `Mass Storage`; future versions might include support for `HID`, `Ethernet`, `MIDI`, `USB webcam`  and more.

## Installation

### Dependencies
Ensure the following dependencies are installed:

```bash
sudo apt install ncurses whiptail
```

### Install Options
1. **Using Debian Package**
   ```bash
   # TODO: Add Vicharak repo to sources
   sudo apt install usb-gadget-manager
   ```

2. **Using Source Code**
   ```bash
   git clone https://github.com/vicharak-in/usb-gadget-manager.git
   cd usb-gadget-manager

   sudo ./setup.sh
   sudo ./tui/main.sh
   ```

## Usage
Run `usb-gadget-manager` to launch the user interface. From the main menu, select the desired USB gadget configuration and enable it.

1. **Confirm Gadget Setup with lsusb**
   After enabling, you can verify that the gadget is recognized using `lsusb`:

   ```bash
   lsusb
   ```
   ```plaintext
   Bus 001 Device 004: ID 8087:0a2a Intel Corp. Bluetooth wireless interface
   Bus 001 Device 008: ID 1d6b:0104 Linux Foundation Multifunction Composite Gadget
   ```

   Look for a new USB composite device in the output list, indicating that the gadget is active and recognized by the system.

### USB Audio Gadget
Enabling the audio gadget through `usb-gadget-manager` will create a virtual sound card on the gadget device.

1. **Confirm Setup with arecord**
   To check that the virtual sound card is available on the gadget device, use:

   ```bash
   arecord -l
   ```

   Expected output includes a virtual USB sound card:

   ```plaintext
   **** List of CAPTURE Hardware Devices ****
   card 5: UAC2Gadget [UAC2_Gadget], device 0: UAC2 PCM [UAC2 PCM]
     Subdevices: 0/1
     Subdevice #0: subdevice #0
   ```

2. **Verify on Host Machine**
   When connected to a host machine, an additional sound card should appear:

   ```bash
   arecord -l
   ```

   Example host output:

   ```plaintext
   **** List of CAPTURE Hardware Devices ****
   card 1: Gadget [USB Gadget], device 0: USB Audio [USB Audio]
     Subdevices: 0/1
     Subdevice #0: subdevice #0
   ```



### Testing and Configuration
To test if the USB Audio Gadget is functioning properly, select `USB Gadget` as the output sound device (playback) on your host device. Then configure your gadget device to redirect sound coming to the virtual USB gadget card to the actual hardware using `alsaloop` or `pactl`. `pactl` is preferred since it doesn't require exclusive access to the sound device.

1. Set the USB gadget as the default output device on the host device, can also done using GUI applications:
   ```bash
   pactl list sinks short
   ```

   Example host output:

   ```plaintext
   48	alsa_output.pci-0000_00_1f.3.analog-stereo	PipeWire	s32le 2ch 48000Hz	IDLE
   283	alsa_output.usb-Vicharak_USB_Gadget_5fdef992060a0a669b-00.analog-stereo	PipeWire	s16le 2ch 96000Hz	RUNNING
   ```
   
   ```bash
   pactl set-default-sink 283
   ```

2. Set up the loopback module on the gadget device:
   ```bash
   pactl list sources short
   ```
   
   Example output:
   ```plaintext
   vicharak@vicharak:~$ pactl list sources short
   0	alsa_output.platform-dp0-sound.stereo-fallback.monitor	module-alsa-card.c	s16le 2ch 44100Hz	SUSPENDED
   1	alsa_output.platform-dp1-sound.stereo-fallback.monitor	module-alsa-card.c	s16le 2ch 44100Hz	SUSPENDED
   2	alsa_output.platform-es8388-sound.HiFi__hw_rockchipes8388__sink.monitor	module-alsa-card.c	s16le 2ch 48000Hz	SUSPENDED
   3	alsa_input.platform-es8388-sound.HiFi__hw_rockchipes8388__source	module-alsa-card.c	s16le 2ch 44100Hz	SUSPENDED
   6	alsa_output.platform-fc000000.usb.stereo-fallback.monitor	module-alsa-card.c	s16le 2ch 96000Hz	IDLE
   7	alsa_input.platform-fc000000.usb.stereo-fallback	module-alsa-card.c	s16le 2ch 96000Hz	RUNNING
   ```

   ```bash
   pactl list sinks short
   ```
   Example output:
   ```plaintext
   vicharak@vicharak:~$ pactl list sinks short
   2	alsa_output.platform-es8388-sound.HiFi__hw_rockchipes8388__sink	module-alsa-card.c	s16le 2ch 48000Hz	SUSPENDED
   4	alsa_output.platform-fc000000.usb.stereo-fallback	module-alsa-card.c	s16le 2ch 96000Hz	RUNNING
   ```
  
   ``` bash
   pactl load-module module-loopback source=7 sink=2
   ```
This setup will create a loopback, forwarding sound from the USB virtual sound card to the `hw_rockchipes8388`. If everything is correctly configured, you should hear sound through the gadget device (stereo/speaker). You may also need to configure the playback device to select stereo or speaker output, which can be done via a GUI or by running `pactl set-default-sink <sink>`.

To remove the loaded loopback module:
   ``` bash
   pactl list modules short
   pactl unload-module 33
   ```


