#!/bin/bash
# shellcheck shell=bash

export GADGET_DIR=/sys/kernel/config/usb_gadget/vicharak

# Default UAC2 audio gadget configuration parameters
export C_SRATE=96000
export P_SRATE=96000
export C_CHMASK=0x03
export P_CHMASK=0x03
export C_SSIZE=0x02
export P_SSIZE=0x02

# Check if UAC2 audio gadget is enabled
is_enable_audio() {
	local LINK="$GADGET_DIR/configs/c.1/uac2.usb0"
	if [ -L "$LINK" ]; then
		#if [ -d "$GADGET_DIR/functions/uac2.usb0" ]; then
		#	return 0
		#fi

		# doesn't matter if directory exists or not, if $LINK exists gadget
		# needs to be reconfigured!
		return 0
	fi
	return 1
}

# Configure and enable UAC2 audio gadget
configfs_add_audio() {
	local flag=0
	# Remove existing audio function link if present
	if [ -e "$GADGET_DIR/configs/c.1/uac2.usb0" ]; then
		rm -rf "$GADGET_DIR/configs/c.1/uac2.usb0" 2>&1
	fi

	# Create audio function directory and set configuration parameters
	mkdir -p "$GADGET_DIR/functions/uac2.usb0" 2>&1 || {
		return 1
	}

	echo "$C_SRATE" >"$GADGET_DIR/functions/uac2.usb0/c_srate" 2>/dev/null || {
		flag=1
		echo "Invalid c_srate: $C_SRATE"
	}

	echo "$P_SRATE" >"$GADGET_DIR/functions/uac2.usb0/p_srate" 2>/dev/null || {
		flag=1
		echo "Invalid p_srate: $P_SRATE"
	}

	echo "$C_CHMASK" >"$GADGET_DIR/functions/uac2.usb0/c_chmask" 2>/dev/null || {
		flag=1
		echo "Invalid c_chmask: $C_CHMASK"
	}

	echo "$P_CHMASK" >"$GADGET_DIR/functions/uac2.usb0/p_chmask" 2>/dev/null || {
		flag=1
		echo "Invalid p_chmask: $P_CHMASK"
	}

	echo "$C_SSIZE" >"$GADGET_DIR/functions/uac2.usb0/c_ssize" 2>/dev/null || {
		flag=1
		echo "Invalid c_ssize: $C_SSIZE"
	}

	echo "$P_SSIZE" >"$GADGET_DIR/functions/uac2.usb0/p_ssize" 2>/dev/null || {
		flag=1
		echo "Invalid p_ssize: $P_SSIZE"
	}

	# Add any other optional configurations here
	#

	if [[ $flag -eq 1 ]]; then
		return 1
	fi

	# Link the audio function to configuration
	ln -s "$GADGET_DIR/functions/uac2.usb0" "$GADGET_DIR/configs/c.1/" 2>&1
}

# Disable and clean up UAC2 audio gadget configuration
configfs_disable_audio() {
	if [ ! -s "$GADGET_DIR/UDC" ]; then
		echo >"$GADGET_DIR/UDC"
	fi

	# Remove the UAC2 audio link from the configuration
	rm -rf "$GADGET_DIR/configs/c.1/uac2.usb0"
	#rm -rf "$GADGET_DIR/functions/uac2.usb0"

	# Optional reboot for full deactivation
	return 0
}
