#!/bin/bash

set -e # Exit immediately if a command exits with a non-zero status.

# Check if the script is run as root
if [[ $EUID -ne 0 ]]; then
	echo "This script must be run as root. Please use sudo."
	exit 1
fi

SCRIPT_PATH="$(dirname "$(realpath "${BASH_SOURCE[0]}")")"

if [ ! -d "/sys/kernel/config/usb_gadget" ]; then
	echo "Error: USB Gadget support is not enabled in the kernel, or the expected directory /sys/kernel/config/usb_gadget does not exist."
	exit 1
fi

# not using debian package installation
if [ ! -f "/usr/local/src/usb-gadget-manager/common/init_configfs.sh" ]; then
	echo "Copying common/init_configfs.sh to /usr/local/src/usb-gadget-manager/"
	sudo mkdir -p "/usr/local/src/usb-gadget-manager/common"
	sudo cp "$SCRIPT_PATH/common/init_configfs.sh" "/usr/local/src/usb-gadget-manager/common/."
fi

if [ ! -f "/etc/systemd/system/usb-gadget.service" ]; then
	echo "Copying usb-gadget.service to /etc/systemd/system/"
	sudo cp "$SCRIPT_PATH/configs/usb-gadget.service" "/etc/systemd/system/usb-gadget.service"

	echo "Enabling and starting usb-gadget.service"
	sudo systemctl enable --now usb-gadget.service
fi

echo "Setup completed successfully!"
