# shellcheck shell=bash

#shellcheck "$PRJ_DIR/common/mass_storage.sh"
source "$PRJ_DIR/common/mass_storage.sh"

MASS_STORAGE_FILE="/dev/mmcblk0"
MASS_STORAGE_REMOVABLE="Y"
MASS_STORAGE_RO="N"
MASS_STORAGE_CDROM="N"

dialog_mass_storage_configure() {
	selected=$(
		__dialog_menu "USB Mass Storage Configuration:" \
			--cancel-button "Save" \
			"<-- Return to main menu" "" \
			"Set regular file/disk path(s) for storage:" "   $MASS_STORAGE_FILE -->" \
			"Is the storage removable? (Y/N):" "   $MASS_STORAGE_REMOVABLE -->" \
			"Set storage as read-only? (N/Y):" "   $MASS_STORAGE_RO -->" \
			"Specify whether each storage should simulate CD-ROM? (Y/N):" "   $MASS_STORAGE_CDROM -->" \
	)

	case $selected in
	"Set regular file/disk"*)
		ret=$(__dialog_inputbox "Enter the file path or image for USB mass storage:" "$MASS_STORAGE_FILE")
		if [[ -n $ret ]]; then
			MASS_STORAGE_FILE=$ret
		else
			__dialog_msgbox "Invalid input. Please enter a valid file path."
		fi
		dialog_mass_storage_configure
		;;

	"Is the storage removable"*)
		ret=$(__dialog_inputbox "Enter 'N' (No) or 'Y' (Yes) to indicate if the storage is removable:" "$MASS_STORAGE_REMOVABLE")
		if [[ $? == 0 ]]; then
			MASS_STORAGE_REMOVABLE=$ret
		fi
		dialog_mass_storage_configure
		;;

	"Set storage as read-only"*)
		ret=$(__dialog_inputbox "Enter 'N' (No) or 'Y' (Yes) to set storage as read-only:" "$MASS_STORAGE_RO")
		if [[ $? == 0 ]]; then
			MASS_STORAGE_RO=$ret
		fi
		dialog_mass_storage_configure
		;;
	"Specify whether each storage"*)
		ret=$(__dialog_inputbox "Enter 'N' (No) or 'Y' (Yes) to emulate storage as cdrom:" "$MASS_STORAGE_CDROM")
		if [[ $? == 0 ]]; then
			MASS_STORAGE_CDROM=$ret
		fi
		dialog_mass_storage_configure
		;;

	\
		*)
		__dialog_yesno "Do you want to apply these configurations?"
		if [[ $? == 0 ]]; then
			# Applying configurations
			retmsg=$(mass_storage_enable 2>&1)
			if [[ $? -eq 1 ]]; then
				__dialog_msgbox "$retmsg \n\n> Please reconfigure!"
			else
				__dialog_msgbox "USB Mass Storage Gadget configured successfully."
			fi
		else
			__dialog_msgbox "Action cancelled, changes not applied."
		fi
		;;
	esac
}

dialog_mass_storage() {
	is_mass_storage_enabled
	if [[ $? == 0 ]]; then
		__dialog_yesno "USB Mass Storage Gadget is already enabled. Do you wish to disable and reconfigure?" --yes-button "Disable & Reconfigure"
		if [[ $? == 0 ]]; then
			mass_storage_disable && dialog_mass_storage_configure
		fi
	else
		dialog_mass_storage_configure
	fi
}
