#!/bin/bash
# shellcheck shell=bash
SCRIPT_PATH="$(dirname "$(realpath "${BASH_SOURCE[0]}")")"
PRJ_DIR="$SCRIPT_PATH/.."

#shellcheck "${SCRIPT_PATH}/utils/dialog.sh"
source "${SCRIPT_PATH}/utils/dialog.sh"

#shellcheck "${SCRIPT_PATH}/dialog_audio.sh"
source "${SCRIPT_PATH}/dialog_audio.sh"

#shellcheck "${SCRIPT_PATH}/../common/audio_gadget.sh"
source "${SCRIPT_PATH}/../common/audio_gadget.sh"

#shellcheck "${SCRIPT_PATH}/../common/common_configsfs.sh"
source "${SCRIPT_PATH}/../common/common_configsfs.sh"

#shellcheck "${SCRIPT_PATH}/dialog_mass_storage.sh"
source "${SCRIPT_PATH}/dialog_mass_storage.sh"

# Check if any gadget configurations are active
is_gadget_configured() {
	if [[ -d "$GADGET_DIR/configs/c.1/uac2.usb0" || -d "$GADGET_DIR/configs/c.1/mass_storage.usb0" || -d "$GADGET_DIR/configs/c.1/hid.usb0" || -d "$GADGET_DIR/configs/c.1/midi.usb0" ]]; then
		return 0
	fi
	return 1
}

# Display main configuration menu
main_menu() {
	if [ ! -d "$GADGET_DIR/configs/c.1" ]; then
		local msg
		msg=$("$SCRIPT_PATH/../setup.sh")
		if [[ $? -eq 1 ]]; then
			__dialog_msgbox "$msg"
			exit 1
		fi
		__dialog_msgbox "$msg"
	fi

	if [ -n "$(cat "$GADGET_DIR/UDC")" ]; then
		#unbind UDC
		echo '' >"$GADGET_DIR/UDC"
	fi

	selection=$(
		__dialog_menu "Select USB Gadget Configuration:" \
			--cancel-button "Enable & Exit" \
			"<-- Back" "   Cancel setup and return to terminal" \
			"Audio Gadget" "   Configure USB Audio Interface Gadget" \
			"Mass Storage" "   Configure USB Mass Storage Gadget" \
			"HID Device" "   Configure USB Human Interface Device (HID) Gadget" \
			"MIDI Device" "   Configure USB MIDI Interface Gadget" \
			"Ethernet Gadget" "   Configure USB Ethernet Gadget"
	)

	case $selection in
	"Audio Gadget")
		dialog_audio
		main_menu
		;;
	"Mass Storage")
		dialog_mass_storage
		main_menu
		;;
	"HID Device")
		__dialog_msgbox "Support for USB HID configuration will be added in future versions."
		main_menu
		;;
	"MIDI Device")
		__dialog_msgbox "Support for USB MIDI configuration will be added in future versions."
		main_menu
		;;
	*Back) ;;

	*)
		# Confirm enabling if any configurations are active
		if is_gadget_configured; then
			enable_confirmed=$(__dialog_yesno "Do you want to activate the configured USB Gadget?")
			if [[ $enable_confirmed -eq 0 ]]; then
				configfs_enable # Activates the configurations
			else
				__dialog_msgbox "USB Gadget activation was canceled."
			fi
		else
			# TODO: add to disable (echo > UDC)
			__dialog_msgbox "No USB Gadget configurations found to enable."
		fi
		;;
	esac
}

# Check if the script is run as root
if [[ $EUID -ne 0 ]]; then
	echo "This script must be run as root. Please use sudo."
	exit 1
fi

main_menu
