# shellcheck shell=bash

VICHARAK_CONFIG_DIALOG=${VICHARAK_CONFIG_DIALOG:-"whiptail"}

__check_terminal() {
	local devices=("/dev/stdin" "/dev/stdout" "/dev/stderr") output disable_stderr
	for i in "${devices[@]}"; do
		disable_stderr="2>&-"
		if [[ $i == "/dev/stderr" ]]; then
			disable_stderr=
		fi

		if output="$(eval "stty size -F '$i' $disable_stderr")"; then
			echo "$output"
			return
		fi
	done
	echo "Unable to get terminal size!" >&2
}

__dialog() {
	local type="$1" text="$2" height width listheight
	shift 2
	height="$(__check_terminal | cut -d ' ' -f 1)"
	width="$(__check_terminal | cut -d ' ' -f 2)"

	# case $box in
	# --menu)
	# 	listheight=0
	# 	;;
	# --checklist | --radiolist)
	# 	listheight=$((height - 8))
	# 	;;
	# esac
	height=$((height - 3))
	width=$((width - 3))
	listheight=$((height - 8))
	if ((height < 8)); then
		echo "TTY height needs to be at least 8 for TUI mode to work, currently is '$height'." >&2
		return 1
	fi

	case $type in
	--inputbox)
		$VICHARAK_CONFIG_DIALOG --title "USB Gadget Manager" \
			--backtitle "	Vicharak" \
			--cancel-button "Exit" "$type" "${text}" "$height" \
			"$width" "$@" 3>&1 1>&2 2>&3 3>&-
		;;
	*)
		$VICHARAK_CONFIG_DIALOG --title "USB Gadget Manager" \
			--backtitle "Vicharak" \
			"$type" "${text}" "$height" \
			"$width" "$listheight" "$@" 3>&1 1>&2 2>&3 3>&-
		;;
	esac

	return $?
}

__dialog_yesno() {
	__dialog --yesno "$@"
	return $?
}

__dialog_msgbox() {
	__dialog --msgbox "$@"
	return $?
}

__dialog_inputbox() {
	__dialog --inputbox "$@"
	return $?
}

__dialog_menu() {
	__dialog --menu "$@"
	return $?
}
